Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(236)

Unified Diff: ppapi/tests/test_graphics_2d.cc

Issue 10832428: Add a query function for the scaling feature. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Test fixed Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/tests/test_graphics_2d.cc
diff --git a/ppapi/tests/test_graphics_2d.cc b/ppapi/tests/test_graphics_2d.cc
index f8f23f5900f80f7215a83df8e303c7ce21f829f2..1c6d69f99bcfa8674a8bd549546d035b1d6316c4 100644
--- a/ppapi/tests/test_graphics_2d.cc
+++ b/ppapi/tests/test_graphics_2d.cc
@@ -632,13 +632,13 @@ std::string TestGraphics2D::TestFlush() {
}
std::string TestGraphics2D::TestDev() {
// Tests GetScale/SetScale via the Graphics2DDev C++ wrapper
const int w=20, h=16;
const float scale=1.0f/2.0f;
pp::Graphics2D dc(instance_, pp::Size(w, h), false);
if (dc.is_null())
return "Failure creating a boring device";
- pp::Graphics2DDev dc_dev(dc);
+ pp::Graphics2D_Dev dc_dev(dc);
if (dc_dev.GetScale() != 1.0f)
return "GetScale returned unexpected value before SetScale";
if (!dc_dev.SetScale(scale))
@@ -632,13 +632,13 @@ std::string TestGraphics2D::TestFlush() {
}
std::string TestGraphics2D::TestDev() {
- // Tests GetScale/SetScale via the Graphics2DDev C++ wrapper
+ // Tests GetScale/SetScale via the Graphics2D_Dev C++ wrapper
const int w=20, h=16;
const float scale=1.0f/2.0f;

Powered by Google App Engine
This is Rietveld 408576698